==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock0.9.tar.gz: hancock/hancock_opt.php <==
<?php
   /**
    **  Displays all options relating to random signatures
    **
    **/

   chdir('..');

   include_once('../src/validate.php');
   include_once('../functions/page_header.php');
   include_once('../functions/display_messages.php');
   include_once('../src/load_prefs.php');

	displayPageHeader($color, 'None');
	global $username, $data_dir;
	$hancockEnabled = getPref($data_dir, $username, 'hancock_enabled');
	$hancockHeader = getPref($data_dir, $username, 'hancock_header');
	$hancockFooter = getPref($data_dir, $username, 'hancock_footer');
	      	$sigs = getPref($data_dir, $username, 'hancock_signatures');

?>

<br>
 <form action="hancock.php" method="post" ENCTYPE="multipart/form-data">
  <table width="95%" align="center" border="1" cellpadding="2" cellspacing="0">
      <tr>
        <td bgcolor="<?php echo $color[0] ?>" colspan="2">
          <center>
            <b><?php echo _("Options") ?> - Random Signatures</b>
          </center>
        </td>
      </tr>
      <tr>
      	<td align="right">Activate</td>
      	<td><input type="checkbox" name="activate" <?php
      	if ($hancockEnabled == 'on') 
      		echo " CHECKED";
      	?>
      	></td>
      </tr>
      <tr>
      	<td>Header:</td>
      	<td><input type="textfield" name="jhheader" size=75 value="<?php echo $hancockHeader ?>"></td>
      </tr>
      <tr>
      	<td>Footer:</td>
      	<td><input type="textfield" name="jhfooter" size=75 value="<?php echo $hancockFooter ?>"></td>
      </tr>
      <tr>
      	<td valign=top>Sigs</td>
      	<td><?php 
    	  	if ($sigs != '') {
    	  		$sigArray = explode("--", $sigs);
    	  		echo "There are " . count($sigArray) . " signatures. <P>";
    	  		//echo $sigArray[1] . ":<p>";
    	  	
    	  	} else {
    	  		echo "No signatures uploaded.";
    	  	}
      	?>
      	<P>
      	<input type="file" name="fname" size="48"> <input type="submit" value="Submit" name="submit_hancock">
		</td>
      </tr>
    </table></form>
    <p>
  </body>
</html>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock-1.4-0.9.tar.gz: hancock/hancock_opt.php <==
<?php
   /**
    **  Displays all options relating to random signatures
    **
    **/


define('SM_PATH','../../');

/* SquirrelMail required files. */
require_once(SM_PATH . 'include/validate.php');
require_once(SM_PATH . 'include/load_prefs.php');
require_once(SM_PATH . 'functions/strings.php');
require_once(SM_PATH . 'functions/page_header.php');

/*
#   include_once('../src/validate.php');
#   include_once('../functions/page_header.php');
#   include_once('../functions/display_messages.php');
#   include_once('../src/load_prefs.php');
*/
	displayPageHeader($color, 'None');
	global $username, $data_dir;
	$hancockEnabled = getPref($data_dir, $username, 'hancock_enabled');
	$hancockHeader = getPref($data_dir, $username, 'hancock_header');
	$hancockFooter = getPref($data_dir, $username, 'hancock_footer');
	      	$sigs = getPref($data_dir, $username, 'hancock_signatures');

?>

<br>
 <form action="hancock.php" method="post" ENCTYPE="multipart/form-data">
  <table width="95%" align="center" border="1" cellpadding="2" cellspacing="0">
      <tr>
        <td bgcolor="<?php echo $color[0] ?>" colspan="2">
          <center>
            <b><?php echo _("Options") ?> - Random Signatures</b>
          </center>
        </td>
      </tr>
      <tr>
      	<td align="right">Activate</td>
      	<td><input type="checkbox" name="activate" <?php
      	if ($hancockEnabled == 'on') 
      		echo " CHECKED";
      	?>
      	></td>
      </tr>
      <tr>
      	<td>Header:</td>
      	<td><input type="textfield" name="jhheader" size=75 value="<?php echo $hancockHeader ?>"></td>
      </tr>
      <tr>
      	<td>Footer:</td>
      	<td><input type="textfield" name="jhfooter" size=75 value="<?php echo $hancockFooter ?>"></td>
      </tr>
      <tr>
      	<td valign=top>Sigs</td>
      	<td><?php 
    	  	if ($sigs != '') {
    	  		$sigArray = explode("--", $sigs);
    	  		echo "There are " . count($sigArray) . " signatures. <P>";
    	  		//echo $sigArray[1] . ":<p>";
    	  	
    	  	} else {
    	  		echo "No signatures uploaded.";
    	  	}
      	?>
      	<P>
      	<input type="file" name="fname" size="48"> <input type="submit" value="Submit" name="submit_hancock">
		</td>
      </tr>
    </table></form>
    <p>
  </body>
</html>
